@@ -28,7 +28,7 @@
 #define UPPER(c) (islower(c) ? toupper(c) : c)
 
 /* The variable hash table */
-#define VAR_HASH_SIZE 64
+#define VAR_HASH_SIZE 67
 #define VARIABLE ErrMsg[E_VAR]
 #define VALUE    ErrMsg[E_VAL]
 #define UNDEF	 ErrMsg[E_UNDEF]
@@ -461,17 +461,17 @@ static int time_sep_func(int do_set, Value *val)
 /***************************************************************/
 unsigned int HashVal(char const *str)
 {
-    register unsigned int i=0;
-    register unsigned int j=1;
-    register unsigned int len=0;
-
-    while(*str && len < VAR_NAME_LEN) {
-	i += j * (unsigned int) UPPER(*str);
-	str++;
-	len++;
-	j = 3-j;
+    unsigned int h = 0, high;
+    while(*str) {
+        h = (h << 4) + (unsigned int) UPPER(*str);
+        str++;
+        high = h & 0xF0000000;
+        if (high) {
+            h ^= (high >> 24);
+        }
+        h &= ~high;
     }
-    return i;
+    return h;
 }
 
 /***************************************************************/
@@ -1208,3 +1208,28 @@ print_sysvar_tokens(void)
         printf("$%s\n", SysVarArr[i].name);
     }
 }
+
+void
+get_var_hash_stats(int *total, int *maxlen, double *avglen)
+{
+    int len;
+    int i;
+    Var *v;
+
+    *maxlen = 0;
+    *total = 0;
+
+    for (i=0; i<VAR_HASH_SIZE; i++) {
+        len = 0;
+        v = VHashTbl[i];
+        while(v) {
+            len++;
+            (*total)++;
+            v = v->next;
+        }
+        if (len > *maxlen) {
+            *maxlen = len;
+        }
+    }
+    *avglen = (double) *total / (double) VAR_HASH_SIZE;
+}
